elephant.spike\_train\_correlation.correlation\_coefficient
===========================================================

.. currentmodule:: elephant.spike_train_correlation

.. autofunction:: correlation_coefficient